// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include <stdio.h>
#include <errno.h>

#include <FL/Fl.H>
#include <FL/Fl_Window.H>
#include <FL/Fl_Repeat_Button.H>
#include <FL/x.H>

#include <flpda/rearg.h>

#include "aqWindow.h"

static aqWindow* win = NULL;
static bool shown = true;

void hide()
{
   win->iconize();
   shown = false;
}

void show()
{
   win->show();
   shown = true;
}

void arg_cb(int c, char** v, void* blah) 
{
	if(shown)
   {
		hide();
   }
	else
   {
		show();
   }
}

int main(int argc, char **argv) 
{
	// Create the main window.
	win = new aqWindow(Fl::w(), Fl::h() / 4);
	win->box(FL_FLAT_BOX);
	win->color(FL_WHITE);

	// Register for "new argument" notification.
	rearg_callback(argv[0], arg_cb,0);

	// Set some window properties.
	// Note: this requires the FLTK "window properties" patch.
	fl_window_properties.layer = 1;//FL_WIN_LAYER_ONTOP;
	fl_window_properties.decoration = FL_WIN_DECORATION_NONE;
	fl_window_properties.hints = FL_WIN_HINTS_DO_NOT_COVER;
	fl_window_properties.flags = FL_WIN_LAYER | FL_WIN_DECORATION | FL_WIN_HINTS;

	// Resize both window and keys.
	//win->resizable(group);
	int h = 60;
	int w = 160;
	win->resize(0, Fl::h() - h, w, h);
	win->resizable(0);

   win->show();

	// Tell the window manager that we never want focus.
	XWMHints hint;
	hint.flags = InputHint;
	hint.input = False;
	XSetWMHints(fl_display, fl_xid(win), &hint);

	Fl::run();

	return 0;
}
